Їхав козак за Дунай, сказав: "Дівчино, прощай! Ти, конику вороненький, неси та гуляй!" Постій, постій, козаче, твоя дівчина плаче, "Як ти ж мене покидаєш – тільки подумай!" Лучше було б, лучше було б не ходить, Лучше було б, лучше було б не любить, Лучше було б, лучше було б та й не знать, Чим тепер, чим тепер забувать. Лучше було б, лучше було б не ходить, Лучше було б, лучше було б не любить, Лучше було б, лучше було б та й не знать, Чим тепер, чим тепер забувать. Вийшла, ручки заломавши і тяженько заплакавши: "Як ти ж мене покидаєш – тільки подумай!" "Білих ручок не ламай, ясних очок не стирай; Мене з війни із славою к собі дожидай." Лучше було б, лучше було б не ходить, Лучше було б, лучше було б не любить, Лучше було б, лучше було б та й не знать, Чим тепер, чим тепер забувать. Лучше було б, лучше було б не ходить, Лучше було б, лучше було б не любить, Лучше було б, лучше було б та й не знать, Чим тепер, чим тепер забувать. "Не хочу я нікого, тільки тебе одного; Ти здоров будь, мій миленький, а все пропадай." Свиснув козак на коня: "Оставайся здорова Як не згину, то вернуся через три года!" Лучше було б, лучше було б не ходить, Лучше було б, лучше було б не любить, Лучше було б, лучше було б та й не знать, Чим тепер, чим тепер забувать. Лучше було б, лучше було б не ходить, Лучше було б, лучше було б не любить, Лучше було б, лучше було б та й не знать, Чим тепер, чим тепер забувать. Лучше було б, лучше було б не ходить, Лучше було б, лучше було б не любить, Лучше було б, лучше було б та й не знать, Чим тепер, чим тепер забувать. Лучше було б, лучше було б не ходить, Лучше було б, лучше було б не любить, Лучше було б, лучше було б та й не знать, Чим тепер, чим тепер забувать.
SHOW FULL COLUMNS FROM `tool_lyric` [ RunTime:0.001172s ]
SELECT `id`,`title`,`singer`,`content` FROM `tool_lyric` WHERE `switch` = 1 AND `id` = 38711 LIMIT 1 [ RunTime:0.001823s ]
UPDATE `tool_lyric` SET `views` = `views` + 1 WHERE `id` = 38711 [ RunTime:0.003328s ]
SELECT `id`,`title` FROM `tool_lyric` WHERE `id` IN (695631,326293,109429,84061,747706,286981,86814,379708,5248,466764,598918,37171,804126,64826,843731,774442,693480,374563,557461,283697,736993,324065,333039,618003,180984,247864,466334,643306,455556,537112) AND `switch` = 1 ORDER BY `views` DESC [ RunTime:0.025589s ]